@@ -3,18 +3,19 @@
 """Misc helper
 """
 
-# Standard libraries.
+# Standard library imports.
 import time
 from enum import Enum, auto
 from datetime import timedelta
 from contextlib import contextmanager
 
 try:
+    # Local library imports.
     from ._version import __version__
 except ImportError:
     __version__ = "0.0.0.invalid0"
 
-__date__ = "2022/04/18 18:18:30 hoel"
+__date__ = "2022/07/30 18:29:32 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 1999, 2000, 2021, 2022 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
@@ -45,17 +46,16 @@ __swirl_string = {
 def swirl(style=SwirlSelect.LINES):
     """Generator to show a swirling life indicator.
 
-Returns:
-    `generator`: printing running indicator.
+    >>> sw = swirl()
+    >>> a = [_ for _ in zip(range(5), sw)]
+    \\...|.../...-...\\...
+    >>> sw = swirl(SwirlSelect.DOTS)
+    >>> a = [_ for _ in zip(range(8), sw)]
+    ⠇...⡆...⣄...⣠...⢰...⠸...⠙...⠋...
 
->>> sw = swirl()
->>> a = [_ for _ in zip(range(5), sw)]
-\\\r|\r/\r-\r\\\r
->>> sw = swirl(SwirlSelect.DOTS)
->>> a = [_ for _ in zip(range(8), sw)]
-⠇\r⡆\r⣄\r⣠\r⢰\r⠸\r⠙\r⠋\r
->>>
-"""
+    Returns:
+      `generator`: printing running indicator.
+    """
     sw_string = __swirl_string[style]
     while True:
         for c in sw_string:
@@ -66,18 +66,18 @@ Returns:
 def count_with_msg(msg="loop", start=0):
     """Counting variable with start value and message.
 
-Args:
-    msg (str): base message
-    start (int): counter start_time
+    >>> c = count_with_msg("msg", 5)
+    >>> print([i for _, i in zip(range(5),c)] == [5, 6, 7, 8, 9])
+    msg 1 ...msg 2 ...msg 3 ...msg 4 ...msg 5 ...True
+    >>>
 
-Returns:
-    `generator`: counter with message.
+    Args:
+        msg (str): base message
+        start (int): counter start_time
 
->>> c = count_with_msg("msg", 5)
->>> print([i for _, i in zip(range(5),c)] == [5, 6, 7, 8, 9])
-msg 1 \rmsg 2 \rmsg 3 \rmsg 4 \rmsg 5 \rTrue
->>>
-"""
+    Returns:
+        `generator`: counter with message.
+    """
     i = 1
     _count = start
     while True:
@@ -91,17 +91,17 @@ msg 1 \rmsg 2 \rmsg 3 \rmsg 4 \rmsg 5 \rTrue
 def process_msg_context(msg):
     """Provides a context for calling routines and reporting entering and exit.
 
-Args:
-    msg (str): message for bracing process.
+    >>> with process_msg_context("do something"):
+    ...     pass
+    do something......do something...done
+    >>>
 
-Returns:
-    `contextmanager`: bracing message.
+    Args:
+        msg (str): message for bracing process.
 
->>> with process_msg_context("do something"):
-...     pass
-do something...\rdo something...done
->>>
-"""
+    Returns:
+        `contextmanager`: bracing message.
+    """
     print("{}...".format(msg), end="\r")
     yield
     print("{}...done".format(msg))
@@ -110,23 +110,23 @@ do something...\rdo something...done
 @contextmanager
 def timed_process_msg_context(msg, time_form=None):
     """Provides a context for calling routines and reporting entering and exit.
-Report spent time.
+    Report spent time.
 
-Args:
-    msg (str): message for bracing process.
-    time_form (func): function formatting druntime.
+    >>> with timed_process_msg_context("do something"):
+    ...     time.sleep(1)
+    do something......do something...done (0:00:01)
+    >>> with timed_process_msg_context("do something", lambda t:"{:d}s".format(int(t))):
+    ...     time.sleep(1)
+    do something......do something...done (1s)
+    >>>
 
-Returns:
-    `contextmanager`: bracing message.
+    Args:
+        msg (str): message for bracing process.
+        time_form (func): function formatting druntime.
 
->>> with timed_process_msg_context("do something"):
-...     time.sleep(1)
-do something...\rdo something...done (0:00:01)
->>> with timed_process_msg_context("do something", lambda t:"{:d}s".format(int(t))):
-...     time.sleep(1)
-do something...\rdo something...done (1s)
->>>
-"""
+    Returns:
+        `contextmanager`: bracing message.
+    """
     if time_form is None:
         time_form = lambda t: timedelta(seconds=int(t))
     start_time = time.time()
